Translate Toolkit 1.5.3
=======================

*Released on 4 February 2010*

Release notes for this release are still to be recovered, feel free to do some
way back searching and create a Pull Request for this release.
